@@ -37,7 +37,7 @@ package Time::OlsonTZ::Data;
 use warnings;
 use strict;
 
-our $VERSION = "0.201807";
+our $VERSION = "0.201808";
 
 use parent "Exporter";
 our @EXPORT_OK = qw(
@@ -77,7 +77,7 @@ retain this format in the future.
 
 =cut
 
-use constant olson_version => "2018g";
+use constant olson_version => "2018h";
 
 =item olson_code_version
 
@@ -89,7 +89,7 @@ piece of information.
 
 =cut
 
-use constant olson_code_version => "2018g";
+use constant olson_code_version => "2018h";
 
 =item olson_data_version
 
@@ -101,7 +101,7 @@ piece of information.
 
 =cut
 
-use constant olson_data_version => "2018g";
+use constant olson_data_version => "2018h";
 
 =back
 
@@ -177,44 +177,45 @@ my $cn = q(+{ map { ($_ => undef) } qw(
 	Asia/Kathmandu Asia/Khandyga Asia/Kolkata Asia/Krasnoyarsk
 	Asia/Kuala_Lumpur Asia/Kuching Asia/Macau Asia/Magadan Asia/Makassar
 	Asia/Manila Asia/Nicosia Asia/Novokuznetsk Asia/Novosibirsk Asia/Omsk
-	Asia/Oral Asia/Pontianak Asia/Pyongyang Asia/Qatar Asia/Qyzylorda
-	Asia/Riyadh Asia/Sakhalin Asia/Samarkand Asia/Seoul Asia/Shanghai
-	Asia/Singapore Asia/Srednekolymsk Asia/Taipei Asia/Tashkent Asia/Tbilisi
-	Asia/Tehran Asia/Thimphu Asia/Tokyo Asia/Tomsk Asia/Ulaanbaatar
-	Asia/Urumqi Asia/Ust-Nera Asia/Vladivostok Asia/Yakutsk Asia/Yangon
-	Asia/Yekaterinburg Asia/Yerevan Atlantic/Azores Atlantic/Bermuda
-	Atlantic/Canary Atlantic/Cape_Verde Atlantic/Faroe Atlantic/Madeira
-	Atlantic/Reykjavik Atlantic/South_Georgia Atlantic/Stanley
-	Australia/Adelaide Australia/Brisbane Australia/Broken_Hill
-	Australia/Currie Australia/Darwin Australia/Eucla Australia/Hobart
-	Australia/Lindeman Australia/Lord_Howe Australia/Melbourne
-	Australia/Perth Australia/Sydney CET CST6CDT EET EST EST5EDT Etc/GMT
-	Etc/GMT+1 Etc/GMT+10 Etc/GMT+11 Etc/GMT+12 Etc/GMT+2 Etc/GMT+3 Etc/GMT+4
-	Etc/GMT+5 Etc/GMT+6 Etc/GMT+7 Etc/GMT+8 Etc/GMT+9 Etc/GMT-1 Etc/GMT-10
-	Etc/GMT-11 Etc/GMT-12 Etc/GMT-13 Etc/GMT-14 Etc/GMT-2 Etc/GMT-3
-	Etc/GMT-4 Etc/GMT-5 Etc/GMT-6 Etc/GMT-7 Etc/GMT-8 Etc/GMT-9 Etc/UCT
-	Etc/UTC Europe/Amsterdam Europe/Andorra Europe/Astrakhan Europe/Athens
-	Europe/Belgrade Europe/Berlin Europe/Brussels Europe/Bucharest
-	Europe/Budapest Europe/Chisinau Europe/Copenhagen Europe/Dublin
-	Europe/Gibraltar Europe/Helsinki Europe/Istanbul Europe/Kaliningrad
-	Europe/Kiev Europe/Kirov Europe/Lisbon Europe/London Europe/Luxembourg
-	Europe/Madrid Europe/Malta Europe/Minsk Europe/Monaco Europe/Moscow
-	Europe/Oslo Europe/Paris Europe/Prague Europe/Riga Europe/Rome
-	Europe/Samara Europe/Saratov Europe/Simferopol Europe/Sofia
-	Europe/Stockholm Europe/Tallinn Europe/Tirane Europe/Ulyanovsk
-	Europe/Uzhgorod Europe/Vienna Europe/Vilnius Europe/Volgograd
-	Europe/Warsaw Europe/Zaporozhye Europe/Zurich Factory HST Indian/Chagos
-	Indian/Christmas Indian/Cocos Indian/Kerguelen Indian/Mahe
-	Indian/Maldives Indian/Mauritius Indian/Reunion MET MST MST7MDT PST8PDT
-	Pacific/Apia Pacific/Auckland Pacific/Bougainville Pacific/Chatham
-	Pacific/Chuuk Pacific/Easter Pacific/Efate Pacific/Enderbury
-	Pacific/Fakaofo Pacific/Fiji Pacific/Funafuti Pacific/Galapagos
-	Pacific/Gambier Pacific/Guadalcanal Pacific/Guam Pacific/Honolulu
-	Pacific/Kiritimati Pacific/Kosrae Pacific/Kwajalein Pacific/Majuro
-	Pacific/Marquesas Pacific/Nauru Pacific/Niue Pacific/Norfolk
-	Pacific/Noumea Pacific/Pago_Pago Pacific/Palau Pacific/Pitcairn
-	Pacific/Pohnpei Pacific/Port_Moresby Pacific/Rarotonga Pacific/Tahiti
-	Pacific/Tarawa Pacific/Tongatapu Pacific/Wake Pacific/Wallis WET
+	Asia/Oral Asia/Pontianak Asia/Pyongyang Asia/Qatar Asia/Qostanay
+	Asia/Qyzylorda Asia/Riyadh Asia/Sakhalin Asia/Samarkand Asia/Seoul
+	Asia/Shanghai Asia/Singapore Asia/Srednekolymsk Asia/Taipei
+	Asia/Tashkent Asia/Tbilisi Asia/Tehran Asia/Thimphu Asia/Tokyo
+	Asia/Tomsk Asia/Ulaanbaatar Asia/Urumqi Asia/Ust-Nera Asia/Vladivostok
+	Asia/Yakutsk Asia/Yangon Asia/Yekaterinburg Asia/Yerevan Atlantic/Azores
+	Atlantic/Bermuda Atlantic/Canary Atlantic/Cape_Verde Atlantic/Faroe
+	Atlantic/Madeira Atlantic/Reykjavik Atlantic/South_Georgia
+	Atlantic/Stanley Australia/Adelaide Australia/Brisbane
+	Australia/Broken_Hill Australia/Currie Australia/Darwin Australia/Eucla
+	Australia/Hobart Australia/Lindeman Australia/Lord_Howe
+	Australia/Melbourne Australia/Perth Australia/Sydney CET CST6CDT EET EST
+	EST5EDT Etc/GMT Etc/GMT+1 Etc/GMT+10 Etc/GMT+11 Etc/GMT+12 Etc/GMT+2
+	Etc/GMT+3 Etc/GMT+4 Etc/GMT+5 Etc/GMT+6 Etc/GMT+7 Etc/GMT+8 Etc/GMT+9
+	Etc/GMT-1 Etc/GMT-10 Etc/GMT-11 Etc/GMT-12 Etc/GMT-13 Etc/GMT-14
+	Etc/GMT-2 Etc/GMT-3 Etc/GMT-4 Etc/GMT-5 Etc/GMT-6 Etc/GMT-7 Etc/GMT-8
+	Etc/GMT-9 Etc/UCT Etc/UTC Europe/Amsterdam Europe/Andorra
+	Europe/Astrakhan Europe/Athens Europe/Belgrade Europe/Berlin
+	Europe/Brussels Europe/Bucharest Europe/Budapest Europe/Chisinau
+	Europe/Copenhagen Europe/Dublin Europe/Gibraltar Europe/Helsinki
+	Europe/Istanbul Europe/Kaliningrad Europe/Kiev Europe/Kirov
+	Europe/Lisbon Europe/London Europe/Luxembourg Europe/Madrid Europe/Malta
+	Europe/Minsk Europe/Monaco Europe/Moscow Europe/Oslo Europe/Paris
+	Europe/Prague Europe/Riga Europe/Rome Europe/Samara Europe/Saratov
+	Europe/Simferopol Europe/Sofia Europe/Stockholm Europe/Tallinn
+	Europe/Tirane Europe/Ulyanovsk Europe/Uzhgorod Europe/Vienna
+	Europe/Vilnius Europe/Volgograd Europe/Warsaw Europe/Zaporozhye
+	Europe/Zurich Factory HST Indian/Chagos Indian/Christmas Indian/Cocos
+	Indian/Kerguelen Indian/Mahe Indian/Maldives Indian/Mauritius
+	Indian/Reunion MET MST MST7MDT PST8PDT Pacific/Apia Pacific/Auckland
+	Pacific/Bougainville Pacific/Chatham Pacific/Chuuk Pacific/Easter
+	Pacific/Efate Pacific/Enderbury Pacific/Fakaofo Pacific/Fiji
+	Pacific/Funafuti Pacific/Galapagos Pacific/Gambier Pacific/Guadalcanal
+	Pacific/Guam Pacific/Honolulu Pacific/Kiritimati Pacific/Kosrae
+	Pacific/Kwajalein Pacific/Majuro Pacific/Marquesas Pacific/Nauru
+	Pacific/Niue Pacific/Norfolk Pacific/Noumea Pacific/Pago_Pago
+	Pacific/Palau Pacific/Pitcairn Pacific/Pohnpei Pacific/Port_Moresby
+	Pacific/Rarotonga Pacific/Tahiti Pacific/Tarawa Pacific/Tongatapu
+	Pacific/Wake Pacific/Wallis WET
 ) });
 sub olson_canonical_names() {
 	$cn = eval($cn) || die $@ if ref($cn) eq "";
